(*
 * <COPYRIGHT>
 * Copyright 2005 Gerd Stolpmann
 *
 * <GPL>
 * This file is part of UMLMON.
 *
 * UMLMON is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * UMLMON is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with UMLMON; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * </>
 *)

(* $Id: umlmon_term.mli 187 2005-10-14 10:54:15Z gerd $ *)

open Umlmon_types

val create_terminals : 
  Unixqueue.unix_event_system -> umlspec -> umlvm -> umlterm_activation list
  (* Creates the PTYs as described in the umlspec. Opens the terminal logfile if 
   * configured. Creates the internal buffer for terminal I/O.
   *)

val shutdown_terminals : umlterm_activation list -> unit
  (* Closes the PTYs and the terminal logfiles. Shuts the internal buffer down.
   * The [umlterm_activation]s are invalid after this call.
   *)

val disconnect_terminals : umlterm_activation list -> unit
  (* Disconnects all terminals *)

val rotate_terminals : umlspec -> umlterm_activation list -> unit
  (* Reopens the terminal log files (after rotation) *)

val proc_connect : 
  Unixqueue.unix_event_system -> 
  umlstatus -> 
  Rpc_server.session ->
  string ->
  (Umlmonctrl_aux.r_connect -> unit) ->
    unit
  (* Implements the [connect] procedure *)

val proc_read :
  Unixqueue.unix_event_system -> 
  umlstatus -> 
  Rpc_server.session ->
  (Umlmonctrl_aux.term_handle * int32) ->
  (Umlmonctrl_aux.r_read -> unit) ->
    unit
  (* Implements the [read] procedure *)

val proc_write :
  Unixqueue.unix_event_system -> 
  umlstatus -> 
  Rpc_server.session ->
  (Umlmonctrl_aux.term_handle * string * int32) ->
  (Umlmonctrl_aux.r_write -> unit) ->
    unit
  (* Implements the [write] procedure *)

val proc_disconnect :
  Unixqueue.unix_event_system -> 
  umlstatus -> 
  Rpc_server.session ->
  (Umlmonctrl_aux.term_handle * bool) ->
  (Umlmonctrl_aux.r_disconnect -> unit) ->
    unit
  (* Implements the [disconnect] procedure *)

val proc_is_connected :
  Unixqueue.unix_event_system -> 
  umlstatus -> 
  Rpc_server.session ->
  string ->
  (bool -> unit) ->
    unit
  (* Implements the [is_connected] procedure *)

val proc_te_init : 
  Unixqueue.unix_event_system -> 
  umlstatus -> 
  Rpc_server.session ->
  (Umlmonctrl_aux.term_handle * int32 * int32) ->
  (Umlmonctrl_aux.r_simple -> unit) ->
    unit
  (* Implements the [te_init] procedure *)

val proc_te_read : 
  Unixqueue.unix_event_system -> 
  umlstatus -> 
  Rpc_server.session ->
  (Umlmonctrl_aux.term_handle * int32) ->
  (Umlmonctrl_aux.r_simple -> unit) ->
    unit
  (* Implements the [te_read] procedure *)

val proc_te_write_keys : 
  Unixqueue.unix_event_system -> 
  umlstatus -> 
  Rpc_server.session ->
  (Umlmonctrl_aux.term_handle * Umlmonctrl_aux.key array * int32) ->
  (Umlmonctrl_aux.r_simple -> unit) ->
    unit
  (* Implements the [te_write_keys] procedure *)

val proc_te_state : 
  Unixqueue.unix_event_system -> 
  umlstatus -> 
  Rpc_server.session ->
  (Umlmonctrl_aux.term_handle) ->
  (Umlmonctrl_aux.r_te_state_opt -> unit) ->
    unit
  (* Implements the [te_state] procedure *)

val proc_te_reset : 
  Unixqueue.unix_event_system -> 
  umlstatus -> 
  Rpc_server.session ->
  (Umlmonctrl_aux.term_handle) ->
  (Umlmonctrl_aux.r_simple -> unit) ->
    unit
  (* Implements the [te_reset] procedure *)
